==> spip_2.0.8.orig.tar.gz: spip-2.0.8.orig/ecrire/lang/public_ast.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Entamu del sitiu',
'articles' => 'Art&iacute;culos',
'articles_auteur' => 'Art&iacute;culos d\'esti autor',
'articles_populaires' => 'Los art&iacute;culos m&aacute;s c&eacute;lebres',
'articles_rubrique' => 'Art&iacute;culos d\'esta estaya',
'aucun_article' => 'N\'esta direici&oacute;n nun hai deng&uacute;n art&iacute;culu',
'aucun_auteur' => 'Nesta direici&oacute;n nun hai deng&uacute;n autor',
'aucun_site' => 'Nesta direici&oacute;n nun hai deng&uacute;n sitiu',
'aucune_breve' => 'Nesta direici&oacute;n nun hai denguna breve',
'aucune_rubrique' => 'Nesta direici&oacute;n nun hai denguna estaya',
'autres' => 'Otros',
'autres_breves' => 'Otres breves',
'autres_groupes_mots_clefs' => 'Otros grupos de pallabres-clave',
'autres_sites' => 'Otros sitios',

// B
'bonjour' => 'Bon d&iacute;a',
'breves' => 'Breves',

// C
'commenter_site' => 'Comentariu so\'l sitiu',
'copie_document_impossible' => 'Nun ye posible copiar el documentu',

// D
'date' => 'Fecha',
'dernier_ajout' => '&Uacute;ltimu a&ntilde;ad&iacute;u',
'dernieres_breves' => '&Uacute;ltimes breves',
'derniers_articles' => '&Uacute;ltimos art&iacute;culos',
'derniers_commentaires' => 'Caberos comentarios',
'derniers_messages_forum' => '&Uacute;ltimos mensaxes espublizaos nos foros',
'documents_interdits_forum' => 'Documentos torgaos nel foru',

// E
'edition_mode_texte' => 'Edici&oacute;n en mou testu de',
'en_reponse' => 'En respuesta a:',
'en_resume' => 'En resumen',
'envoyer_message' => 'Mandar un mensaxe',
'espace_prive' => 'Espaciu acut&aacute;u',

// F
'formats_acceptes' => 'Formats aceptaos: @formats@.',
'forum' => 'Foru',

// H
'hierarchie_site' => 'Xerarqu&iacute;a del sitiu',

// J
'jours' => 'd&iacute;es',

// L
'lien_connecter' => 'Coneutase',

// M
'meme_auteur' => 'Del mesmu autor',
'meme_rubrique' => 'Na mesma estaya',
'memes_auteurs' => 'De los mesmos autores',
'message' => 'Mensaxe',
'messages_forum' => 'Mensaxes del foru',
'messages_recents' => 'Mensaxes m&aacute;s nuevos nos foros',
'mots_clefs' => 'Pallabres-clave',
'mots_clefs_meme_groupe' => 'Pallabres-clave nel mesmu grupu',

// N
'navigation' => 'Navegaci&oacute;n',
'nom' => 'Nome',
'nouveautes' => 'Les noved&aacute;es',
'nouveautes_web' => 'Noved&aacute;es na Web',
'nouveaux_articles' => 'Art&iacute;culos nuevos',
'nouvelles_breves' => 'Breves nueves',

// P
'page_precedente' => 'p&aacute;xina anterior',
'page_suivante' => 'p&aacute;xina siguiente',
'par_auteur' => 'por ',
'participer_site' => 'Puedes participar na vida d\'esti sitiu y proponer los tos propios art&iacute;culos apunt&aacute;ndote equ&iacute;. Vas recibir de secute un corr&eacute;u electr&oacute;nicu colos tos c&oacute;digos pa poder entrar nel espaciu privau del sitiu.',
'plan_site' => 'Mapa d\'esti sitiu',
'popularite' => 'Popularid&aacute;',
'poster_message' => 'Unviar un mensaxe',
'proposer_site' => 'Puedes proponer un sitiu Web pa amestar nesta seici&oacute;n:',

// R
'repondre_article' => 'Responder a esti art&iacute;culu',
'repondre_breve' => 'Responder a esta breve',
'repondre_message' => 'Responder a esti mensaxe',
'resultats_recherche' => 'Resultaos de la gueta',
'retour_debut_forums' => 'Tornar al entamu los foros',
'rubrique' => 'Estaya',
'rubriques' => 'Estayes',

// S
'signatures_petition' => 'Firmes',
'site_realise_avec_spip' => 'Sitiu fechu mand&aacute;ndose de SPIP',
'sites_web' => 'Sitios Web',
'sous_rubriques' => 'Sub-estayes',
'spam' => 'Puxarra',
'suite' => 'sigue',
'sur_web' => 'Na Rede',
'syndiquer_rubrique' => 'Sindicar esta seici&oacute;n',
'syndiquer_site' => 'Sindicar tou el sitiu',

// T
'texte_lettre_information' => 'Esta ye la carta informativa del sitiu',
'texte_lettre_information_2' => 'Esta carta recueye los art&iacute;culos y les breves espublizaos dende',

// V
'ver_imprimer' => 'Versi&oacute;n pa imprentar',
'voir_en_ligne' => 'Velo en ll&iacute;nia',
'voir_squelette' => 'ver la cadarma d\'esta p&aacute;xina'
);

?>

==> spip_2.1.orig.tar.gz: spip-2.1.orig/ecrire/lang/public_ast.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Entamu del sitiu',
'article' => 'Article', # NEW
'articles' => 'Art&iacute;culos',
'articles_auteur' => 'Art&iacute;culos d\'esti autor',
'articles_populaires' => 'Los art&iacute;culos m&aacute;s c&eacute;lebres',
'articles_rubrique' => 'Art&iacute;culos d\'esta estaya',
'aucun_article' => 'N\'esta direici&oacute;n nun hai deng&uacute;n art&iacute;culu',
'aucun_auteur' => 'Nesta direici&oacute;n nun hai deng&uacute;n autor',
'aucun_site' => 'Nesta direici&oacute;n nun hai deng&uacute;n sitiu',
'aucune_breve' => 'Nesta direici&oacute;n nun hai denguna breve',
'aucune_rubrique' => 'Nesta direici&oacute;n nun hai denguna estaya',
'auteur' => 'Auteur', # NEW
'autres' => 'Otros',
'autres_breves' => 'Otres breves',
'autres_groupes_mots_clefs' => 'Otros grupos de pallabres-clave',
'autres_sites' => 'Otros sitios',

// B
'bonjour' => 'Bon d&iacute;a',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'Breves',

// C
'commenter_site' => 'Comentariu so\'l sitiu',
'copie_document_impossible' => 'Nun ye posible copiar el documentu',

// D
'date' => 'Fecha',
'dernier_ajout' => '&Uacute;ltimu a&ntilde;ad&iacute;u',
'dernieres_breves' => '&Uacute;ltimes breves',
'derniers_articles' => '&Uacute;ltimos art&iacute;culos',
'derniers_commentaires' => 'Caberos comentarios',
'derniers_messages_forum' => '&Uacute;ltimos mensaxes espublizaos nos foros',
'documents_interdits_forum' => 'Documentos torgaos nel foru',

// E
'edition_mode_texte' => 'Edici&oacute;n en mou testu de',
'en_reponse' => 'En respuesta a:',
'en_resume' => 'En resumen',
'envoyer_message' => 'Mandar un mensaxe',
'espace_prive' => 'Espaciu acut&aacute;u',

// F
'formats_acceptes' => 'Formats aceptaos: @formats@.',
'forum' => 'Foru',

// H
'hierarchie_site' => 'Xerarqu&iacute;a del sitiu',

// J
'jours' => 'd&iacute;es',

// L
'lien_connecter' => 'Coneutase',

// M
'meme_auteur' => 'Del mesmu autor',
'meme_rubrique' => 'Na mesma estaya',
'memes_auteurs' => 'De los mesmos autores',
'message' => 'Mensaxe',
'messages_forum' => 'Mensaxes del foru',
'messages_recents' => 'Mensaxes m&aacute;s nuevos nos foros',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'Pallabres-clave',
'mots_clefs_meme_groupe' => 'Pallabres-clave nel mesmu grupu',

// N
'navigation' => 'Navegaci&oacute;n',
'nom' => 'Nome',
'nouveautes' => 'Les noved&aacute;es',
'nouveautes_web' => 'Noved&aacute;es na Web',
'nouveaux_articles' => 'Art&iacute;culos nuevos',
'nouvelles_breves' => 'Breves nueves',

// P
'page_precedente' => 'p&aacute;xina anterior',
'page_suivante' => 'p&aacute;xina siguiente',
'par_auteur' => 'por ',
'participer_site' => 'Puedes participar na vida d\'esti sitiu y proponer los tos propios art&iacute;culos apunt&aacute;ndote equ&iacute;. Vas recibir de secute un corr&eacute;u electr&oacute;nicu colos tos c&oacute;digos pa poder entrar nel espaciu privau del sitiu.',
'plan_site' => 'Mapa d\'esti sitiu',
'popularite' => 'Popularid&aacute;',
'poster_message' => 'Unviar un mensaxe',
'proposer_site' => 'Puedes proponer un sitiu Web pa amestar nesta seici&oacute;n:',

// R
'repondre_article' => 'Responder a esti art&iacute;culu',
'repondre_breve' => 'Responder a esta breve',
'repondre_message' => 'Responder a esti mensaxe',
'resultats_recherche' => 'Resultaos de la gueta',
'retour_debut_forums' => 'Tornar al entamu los foros',
'rubrique' => 'Estaya',
'rubriques' => 'Estayes',

// S
'signatures_petition' => 'Firmes',
'site_realise_avec_spip' => 'Sitiu fechu mand&aacute;ndose de SPIP',
'sites_web' => 'Sitios Web',
'sous_rubriques' => 'Sub-estayes',
'spam' => 'Puxarra',
'suite' => 'sigue',
'sur_web' => 'Na Rede',
'syndiquer_rubrique' => 'Sindicar esta seici&oacute;n',
'syndiquer_site' => 'Sindicar tou el sitiu',

// T
'texte_lettre_information' => 'Esta ye la carta informativa del sitiu',
'texte_lettre_information_2' => 'Esta carta recueye los art&iacute;culos y les breves espublizaos dende',

// V
'ver_imprimer' => 'Versi&oacute;n pa imprentar',
'voir_en_ligne' => 'Velo en ll&iacute;nia',
'voir_squelette' => 'ver la cadarma d\'esta p&aacute;xina'
);

?>
